@@ -18,17 +18,32 @@
 # the LICENSES folder.
 
 from dataclasses import dataclass
-from multiprocessing import Pool, Value, cpu_count
-from typing import Callable, List, Tuple, Optional
+from multiprocessing import (
+    Pool,
+    Value,
+    cpu_count,
+)
+from typing import (
+    Callable,
+    List,
+    Tuple,
+    Optional,
+)
 from traceback import format_exc
-from lmfit import minimize, Parameters
+from lmfit import (
+    Parameters,
+    minimize,
+)
 from lmfit.minimizer import MinimizerResult
 from numpy import (
     abs,
     angle,
     array,
     float64,
+    floating,
     inf,
+    integer,
+    issubdtype,
     log10 as log,
     min,
     max,
@@ -37,7 +52,10 @@ from numpy import (
     sum as array_sum,
     zeros,
 )
-from numpy.linalg import pinv, inv
+from numpy.linalg import (
+    inv,
+    pinv,
+)
 from pyimpspec.analysis.fitting import (
     _from_lmfit,
     _to_lmfit,
@@ -54,33 +72,33 @@ from pyimpspec.data import DataSet
 @dataclass(frozen=True)
 class KramersKronigResult:
     """
-An object representing the results of a linear Kramers-Kronig test applied to a data set.
+    An object representing the results of a linear Kramers-Kronig test applied to a data set.
 
-Parameters
-----------
-circuit: Circuit
-    The fitted circuit.
+    Parameters
+    ----------
+    circuit: Circuit
+        The fitted circuit.
 
-num_RC: int
-    The final number of parallel RC circuits in the fitted model (Boukamp, 1995).
+    num_RC: int
+        The final number of RC elements in the fitted model (Boukamp, 1995).
 
-mu: float
-    The mu-value of the final fit (eq. 21 in Schönleber et al., 2014).
+    mu: float
+        The mu-value of the final fit (eq. 21 in Schönleber et al., 2014).
 
-pseudo_chisqr: float
-    The pseudo chi-squared fit value (eq. 14 in Boukamp, 1995).
+    pseudo_chisqr: float
+        The pseudo chi-squared fit value (eq. 14 in Boukamp, 1995).
 
-frequency: ndarray
-    The frequencies used to perform the test.
+    frequency: ndarray
+        The frequencies used to perform the test.
 
-impedance: ndarray
-    The impedance produced by the fitted circuit at each of the tested frequencies.
+    impedance: ndarray
+        The impedance produced by the fitted circuit at each of the tested frequencies.
 
-real_residual: ndarray
-    The residuals for the real parts (eq. 15 in Schönleber et al., 2014).
+    real_residual: ndarray
+        The residuals for the real parts (eq. 15 in Schönleber et al., 2014).
 
-imaginary_residual: ndarray
-    The residuals for the imaginary parts (eq. 16 in Schönleber et al., 2014).
+    imaginary_residual: ndarray
+        The residuals for the imaginary parts (eq. 16 in Schönleber et al., 2014).
     """
 
     circuit: Circuit
@@ -96,30 +114,30 @@ imaginary_residual: ndarray
         return f"KramersKronigResult (num_RC={self.num_RC}, {hex(id(self))})"
 
     def get_frequency(self, num_per_decade: int = -1) -> ndarray:
-        assert type(num_per_decade) is int
+        assert issubdtype(type(num_per_decade), integer), num_per_decade
         if num_per_decade > 0:
             return _interpolate(self.frequency, num_per_decade)
         return self.frequency
 
     def get_impedance(self, num_per_decade: int = -1) -> ndarray:
-        assert type(num_per_decade) is int
+        assert issubdtype(type(num_per_decade), integer), num_per_decade
         if num_per_decade > 0:
             return self.circuit.impedances(self.get_frequency(num_per_decade))
         return self.impedance
 
     def get_nyquist_data(self, num_per_decade: int = -1) -> Tuple[ndarray, ndarray]:
         """
-Get the data necessary to plot this KramersKronigResult as a Nyquist plot: the real and the negative imaginary parts of the impedances.
+        Get the data necessary to plot this KramersKronigResult as a Nyquist plot: the real and the negative imaginary parts of the impedances.
 
-Parameters
-----------
-num_per_decade: int = -1
+        Parameters
+        ----------
+        num_per_decade: int = -1
 
-Returns
--------
-Tuple[ndarray, ndarray]
+        Returns
+        -------
+        Tuple[ndarray, ndarray]
         """
-        assert type(num_per_decade) is int
+        assert issubdtype(type(num_per_decade), integer), num_per_decade
         if num_per_decade > 0:
             Z: ndarray = self.get_impedance(num_per_decade)
             return (
@@ -135,17 +153,17 @@ Tuple[ndarray, ndarray]
         self, num_per_decade: int = -1
     ) -> Tuple[ndarray, ndarray, ndarray]:
         """
-Get the data necessary to plot this KramersKronigResult as a Bode plot: the base-10 logarithms of the frequencies, the base-10 logarithms of the absolute magnitudes of the impedances, and the negative phase angles/shifts of the impedances in degrees.
+        Get the data necessary to plot this KramersKronigResult as a Bode plot: the base-10 logarithms of the frequencies, the base-10 logarithms of the absolute magnitudes of the impedances, and the negative phase angles/shifts of the impedances in degrees.
 
-Parameters
-----------
-num_per_decade: int = -1
+        Parameters
+        ----------
+        num_per_decade: int = -1
 
-Returns
--------
-Tuple[ndarray, ndarray, ndarray]
+        Returns
+        -------
+        Tuple[ndarray, ndarray, ndarray]
         """
-        assert type(num_per_decade) is int
+        assert issubdtype(type(num_per_decade), integer), num_per_decade
         if num_per_decade > 0:
             freq: ndarray = self.get_frequency(num_per_decade)
             Z: ndarray = self.circuit.impedances(freq)
@@ -162,11 +180,11 @@ Tuple[ndarray, ndarray, ndarray]
 
     def get_residual_data(self) -> Tuple[ndarray, ndarray, ndarray]:
         """
-Get the data necessary to plot the relative residuals for this KramersKronigResult: the base-10 logarithms of the frequencies, the relative residuals for the real parts of the impedances in percents, and the relative residuals for the imaginary parts of the impedances in percents.
+        Get the data necessary to plot the relative residuals for this KramersKronigResult: the base-10 logarithms of the frequencies, the relative residuals for the real parts of the impedances in percents, and the relative residuals for the imaginary parts of the impedances in percents.
 
-Returns
--------
-Tuple[ndarray, ndarray, ndarray]
+        Returns
+        -------
+        Tuple[ndarray, ndarray, ndarray]
         """
         return (
             log(self.frequency),
@@ -177,16 +195,16 @@ Tuple[ndarray, ndarray, ndarray]
 
 def _calculate_tau(i: int, num_RC: int, tau_min: float64, tau_max: float64) -> float:
     # Calculate time constants according to eq. 12 in Schönleber et al. (2014)
-    assert type(i) is int
-    assert type(num_RC) is int
-    assert type(tau_min) is float64
-    assert type(tau_max) is float64
+    assert issubdtype(type(i), integer), i
+    assert issubdtype(type(num_RC), integer), num_RC
+    assert issubdtype(type(tau_min), floating), tau_min
+    assert issubdtype(type(tau_max), floating), tau_max
     return pow(10, (log(tau_min) + (i - 1) / (num_RC - 1) * log(tau_max / tau_min)))
 
 
 def _generate_time_constants(w: ndarray, num_RC: int) -> ndarray:
-    assert type(w) is ndarray
-    assert type(num_RC) is int
+    assert type(w) is ndarray, w
+    assert issubdtype(type(num_RC), integer), num_RC
     taus: ndarray = zeros(shape=(num_RC,))
     tau_min: float64 = 1 / max(w)
     tau_max: float64 = 1 / min(w)
@@ -200,15 +218,15 @@ def _generate_time_constants(w: ndarray, num_RC: int) -> ndarray:
 
 
 def _generate_weight(Z_exp: ndarray) -> ndarray:
-    assert type(Z_exp) is ndarray
+    assert type(Z_exp) is ndarray, Z_exp
     # See eq. 13 in Boukamp (1995)
     return (Z_exp.real**2 + Z_exp.imag**2) ** -1
 
 
 def _calculate_pseudo_chisqr(Z_exp: ndarray, Z_fit: ndarray, weight: ndarray) -> float:
-    assert type(Z_exp) is ndarray
-    assert type(Z_fit) is ndarray
-    assert type(weight) is ndarray
+    assert type(Z_exp) is ndarray, Z_exp
+    assert type(Z_fit) is ndarray, Z_fit
+    assert type(weight) is ndarray, weight
     # See eq. 14 in Boukamp (1995)
     return float(
         array_sum(
@@ -218,7 +236,7 @@ def _calculate_pseudo_chisqr(Z_exp: ndarray, Z_fit: ndarray, weight: ndarray) ->
 
 
 def _calculate_mu(params: Parameters) -> float:
-    assert type(params) is Parameters
+    assert type(params) is Parameters, params
     # Calculates the mu-value based on the fitted parameters according to eq. 21 in
     # Schönleber et al. (2014)
     R_neg: List[float] = []
@@ -249,9 +267,9 @@ def _calculate_mu(params: Parameters) -> float:
 def _elements_to_parameters(
     elements: ndarray, taus: ndarray, add_capacitance: bool
 ) -> Parameters:
-    assert type(elements) is ndarray
-    assert type(taus) is ndarray
-    assert type(add_capacitance) is bool
+    assert type(elements) is ndarray, elements
+    assert type(taus) is ndarray, taus
+    assert type(add_capacitance) is bool, add_capacitance
     parameters: Parameters = Parameters()
     R0: float
     R0, elements = elements[0], elements[1:]
@@ -275,11 +293,11 @@ def _elements_to_parameters(
 def _complex_residual(
     params: Parameters, circuit: Circuit, freq: ndarray, Z_exp: ndarray, weight: ndarray
 ) -> ndarray:
-    assert type(params) is Parameters
-    assert type(circuit) is Circuit
-    assert type(freq) is ndarray
-    assert type(Z_exp) is ndarray
-    assert type(weight) is ndarray
+    assert type(params) is Parameters, params
+    assert type(circuit) is Circuit, circuit
+    assert type(freq) is ndarray, freq
+    assert type(Z_exp) is ndarray, Z_exp
+    assert type(weight) is ndarray, weight
     circuit.set_parameters(_from_lmfit(params))
     Z_fit: ndarray = circuit.impedances(freq)
     return array(
@@ -309,14 +327,14 @@ def _cnls_test(arguments: tuple) -> Tuple[int, float, Circuit, float]:
         method,
         max_nfev,
     ) = arguments
-    assert type(freq) is ndarray
-    assert type(Z_exp) is ndarray
-    assert type(weight) is ndarray
-    assert type(num_RC) is int
-    assert type(add_capacitance) is bool
-    assert type(add_inductance) is bool
-    assert type(method) is str
-    assert type(max_nfev) is int
+    assert type(freq) is ndarray, freq
+    assert type(Z_exp) is ndarray, Z_exp
+    assert type(weight) is ndarray, weight
+    assert issubdtype(type(num_RC), integer), num_RC
+    assert type(add_capacitance) is bool, add_capacitance
+    assert type(add_inductance) is bool, add_inductance
+    assert type(method) is str, method
+    assert issubdtype(type(max_nfev), integer), max_nfev
     w: ndarray = 2 * pi * freq
     taus: ndarray = _generate_time_constants(w, num_RC)
     circuit: Circuit = _generate_circuit(taus, add_capacitance, add_inductance, True)
@@ -348,13 +366,13 @@ def _cnls_test(arguments: tuple) -> Tuple[int, float, Circuit, float]:
     )
 
 
-# A shared integer value, which represents the smallest number of (RC) circuits that has resulted
+# A shared integer value, which represents the smallest number of RC elements that has resulted
 # in a mu-value that is less than the chosen mu-criterion. If this value is negative, then an
-# appropriate number of (RC) circuits has not yet been found. However, if the value is greater than
-# the number of (RC) circuits currently being evaluated by the process accessing the value, then
+# appropriate number of RC elements has not yet been found. However, if the value is greater than
+# the number of RC elements currently being evaluated by the process accessing the value, then
 # the process should continue performing the current fitting. Otherwise, any ongoing fitting should
 # be terminated as soon as possible and no further attempts should be made with a greater number of
-# (RC) circuits.
+# RC elements.
 pool_optimal_num_RC = None  # multiprocessing.Value
 
 
@@ -387,15 +405,15 @@ def _cnls_mu_process(args: tuple) -> Tuple[int, float, Optional[Circuit], float]
         method,
         max_nfev,
     ) = args
-    assert type(freq) is ndarray
-    assert type(Z_exp) is ndarray
-    assert type(weight) is ndarray
-    assert type(mu_criterion) is float
-    assert type(num_RC) is int
-    assert type(add_capacitance) is bool
-    assert type(add_inductance) is bool
-    assert type(method) is str
-    assert type(max_nfev) is int
+    assert type(freq) is ndarray, freq
+    assert type(Z_exp) is ndarray, Z_exp
+    assert type(weight) is ndarray, weight
+    assert issubdtype(type(mu_criterion), floating), mu_criterion
+    assert issubdtype(type(num_RC), integer), num_RC
+    assert type(add_capacitance) is bool, add_capacitance
+    assert type(add_inductance) is bool, add_inductance
+    assert type(method) is str, method
+    assert issubdtype(type(max_nfev), integer), max_nfev
 
     def exit_early(params: Parameters, i: int, _, *args, **kwargs):
         if 0 <= pool_optimal_num_RC.value < num_RC:  # type: ignore
@@ -444,11 +462,11 @@ def _cnls_mu_process(args: tuple) -> Tuple[int, float, Optional[Circuit], float]
 def _generate_variable_matrices(
     w: ndarray, num_RC: int, taus: ndarray, add_capacitance: bool, abs_Z_exp: ndarray
 ) -> Tuple[ndarray, ndarray]:
-    assert type(w) is ndarray
-    assert type(num_RC) is int
-    assert type(taus) is ndarray
-    assert type(add_capacitance) is bool
-    assert type(abs_Z_exp) is ndarray
+    assert type(w) is ndarray, w
+    assert issubdtype(type(num_RC), integer), num_RC
+    assert type(taus) is ndarray, taus
+    assert type(add_capacitance) is bool, add_capacitance
+    assert type(abs_Z_exp) is ndarray, abs_Z_exp
     # Generate matrices with the following columns (top to bottom is left to right)
     # - R0, series resistance
     # - Ri, resistance in parallel with taus[i - 1] where 0 < i <= num_RC
@@ -466,7 +484,7 @@ def _generate_variable_matrices(
     a_re[:, 0] = 1 / abs_Z_exp  # No imaginary part
     # Series inductance
     a_im[:, -1] = w / abs_Z_exp  # No real part
-    # Parallel RC circuits
+    # RC elements
     for i, tau in enumerate(taus):
         a_re[:, i + 1] = (1 / (1 + 1j * w * tau)).real / abs_Z_exp
         a_im[:, i + 1] = (1 / (1 + 1j * w * tau)).imag / abs_Z_exp
@@ -479,10 +497,10 @@ def _generate_variable_matrices(
 def _generate_circuit(
     taus: ndarray, add_capacitance: bool, add_inductance: bool, cnls: bool
 ) -> Circuit:
-    assert type(taus) is ndarray
-    assert type(add_capacitance) is bool
-    assert type(add_inductance) is bool
-    assert type(cnls) is bool
+    assert type(taus) is ndarray, taus
+    assert type(add_capacitance) is bool, add_capacitance
+    assert type(add_inductance) is bool, add_inductance
+    assert type(cnls) is bool, cnls
     cdc: List[str] = ["R{R=1}"]
     t: float
     for t in taus:
@@ -513,15 +531,15 @@ def _real_test(
     add_capacitance: bool,
     circuit: Circuit,
 ):
-    assert type(a_re) is ndarray
-    assert type(a_im) is ndarray
-    assert type(Z_exp) is ndarray
-    assert type(abs_Z_exp) is ndarray
-    assert type(w) is ndarray
-    assert type(freq) is ndarray
-    assert type(taus) is ndarray
-    assert type(add_capacitance) is bool
-    assert type(circuit) is Circuit
+    assert type(a_re) is ndarray, a_re
+    assert type(a_im) is ndarray, a_im
+    assert type(Z_exp) is ndarray, Z_exp
+    assert type(abs_Z_exp) is ndarray, abs_Z_exp
+    assert type(w) is ndarray, w
+    assert type(freq) is ndarray, freq
+    assert type(taus) is ndarray, taus
+    assert type(add_capacitance) is bool, add_capacitance
+    assert type(circuit) is Circuit, circuit
     # Fit using the real part
     elements: ndarray = pinv(a_re).dot(Z_exp.real / abs_Z_exp)
     # Fit using the imaginary part to fix the series inductance (and capacitance)
@@ -555,14 +573,14 @@ def _imaginary_test(
     weight: ndarray,
     circuit: Circuit,
 ):
-    assert type(a_im) is ndarray
-    assert type(Z_exp) is ndarray
-    assert type(abs_Z_exp) is ndarray
-    assert type(freq) is ndarray
-    assert type(taus) is ndarray
-    assert type(add_capacitance) is bool
-    assert type(weight) is ndarray
-    assert type(circuit) is Circuit
+    assert type(a_im) is ndarray, a_im
+    assert type(Z_exp) is ndarray, Z_exp
+    assert type(abs_Z_exp) is ndarray, abs_Z_exp
+    assert type(freq) is ndarray, freq
+    assert type(taus) is ndarray, taus
+    assert type(add_capacitance) is bool, add_capacitance
+    assert type(weight) is ndarray, weight
+    assert type(circuit) is Circuit, circuit
     # Fit using the imaginary part
     elements: ndarray = pinv(a_im).dot(Z_exp.imag / abs_Z_exp)
     # Estimate the series resistance
@@ -585,13 +603,13 @@ def _complex_test(
     add_capacitance: bool,
     circuit: Circuit,
 ):
-    assert type(a_re) is ndarray
-    assert type(a_im) is ndarray
-    assert type(Z_exp) is ndarray
-    assert type(abs_Z_exp) is ndarray
-    assert type(taus) is ndarray
-    assert type(add_capacitance) is bool
-    assert type(circuit) is Circuit
+    assert type(a_re) is ndarray, a_re
+    assert type(a_im) is ndarray, a_im
+    assert type(Z_exp) is ndarray, Z_exp
+    assert type(abs_Z_exp) is ndarray, abs_Z_exp
+    assert type(taus) is ndarray, taus
+    assert type(add_capacitance) is bool, add_capacitance
+    assert type(circuit) is Circuit, circuit
     # Fit using the complex impedance
     x: ndarray = inv(a_re.T.dot(a_re) + a_im.T.dot(a_im))
     y: ndarray = a_re.T.dot(Z_exp.real / abs_Z_exp) + a_im.T.dot(Z_exp.imag / abs_Z_exp)
@@ -609,12 +627,12 @@ def _test_wrapper(arguments: tuple) -> Tuple[int, float, Circuit, float]:
     num_RC: int
     add_capacitance: bool
     test, freq, Z_exp, weight, num_RC, add_capacitance = arguments
-    assert type(test) is str
-    assert type(freq) is ndarray
-    assert type(Z_exp) is ndarray
-    assert type(weight) is ndarray
-    assert type(num_RC) is int
-    assert type(add_capacitance) is bool
+    assert type(test) is str, test
+    assert type(freq) is ndarray, freq
+    assert type(Z_exp) is ndarray, Z_exp
+    assert type(weight) is ndarray, weight
+    assert issubdtype(type(num_RC), integer), num_RC
+    assert type(add_capacitance) is bool, add_capacitance
     abs_Z_exp: ndarray = abs(Z_exp)
     w: ndarray = 2 * pi * freq
     taus: ndarray = _generate_time_constants(w, num_RC)
@@ -659,57 +677,57 @@ def perform_test(
     num_procs: int = -1,
 ) -> KramersKronigResult:
     """
-Performs a linear Kramers-Kronig test as described by Boukamp (1995).
-The results can be used to check the validity of an impedance spectrum before performing equivalent circuit fitting.
-If the number of (RC) circuits is less than two, then a suitable number of (RC) circuits is determined using the procedure described by Schönleber et al.(2014) based on a criterion for the calculated mu-value (zero to one).
-A mu-value of one represents underfitting and a mu-value of zero represents overfitting.
+    Performs a linear Kramers-Kronig test as described by Boukamp (1995).
+    The results can be used to check the validity of an impedance spectrum before performing equivalent circuit fitting.
+    If the number of RC elements is less than two, then a suitable number of RC elements is determined using the procedure described by Schönleber et al. (2014) based on a criterion for the calculated mu-value (zero to one).
+    A mu-value of one represents underfitting and a mu-value of zero represents overfitting.
 
-References:
+    References:
 
-- B.A. Boukamp, 1995, J. Electrochem. Soc., 142, 1885-1894 (https://doi.org/10.1149/1.2044210)
-- M. Schönleber, D. Klotz, and E. Ivers-Tiffée, 2014, Electrochim. Acta, 131, 20-27 (https://doi.org/10.1016/j.electacta.2014.01.034)
+    - B.A. Boukamp, 1995, J. Electrochem. Soc., 142, 1885-1894 (https://doi.org/10.1149/1.2044210)
+    - M. Schönleber, D. Klotz, and E. Ivers-Tiffée, 2014, Electrochim. Acta, 131, 20-27 (https://doi.org/10.1016/j.electacta.2014.01.034)
 
-Parameters
-----------
-data: DataSet
-    The data set to be tested.
+    Parameters
+    ----------
+    data: DataSet
+        The data set to be tested.
 
-test: str = "complex"
-    Supported values include "cnls", "complex", "imaginary", and "real". The "cnls" test performs a complex non-linear least squares fit using lmfit.minimize, which usually provides a good fit but is also quite slow.
-    The "complex", "imaginary", and "real" tests perform the complex, imaginary, and real tests, respectively, according to Boukamp (1995).
+    test: str = "complex"
+        Supported values include "cnls", "complex", "imaginary", and "real". The "cnls" test performs a complex non-linear least squares fit using lmfit.minimize, which usually provides a good fit but is also quite slow.
+        The "complex", "imaginary", and "real" tests perform the complex, imaginary, and real tests, respectively, according to Boukamp (1995).
 
-num_RC: int = 0
-    The number of parallel RC circuits to use.
-    A value less than one results in the use of the procedure described by Schönleber et al. (2014) based on the chosen mu-criterion.
+    num_RC: int = 0
+        The number of RC elements to use.
+        A value less than one results in the use of the procedure described by Schönleber et al. (2014) based on the chosen mu-criterion.
 
-mu_criterion: float = 0.85
-    The chosen mu-criterion. See Schönleber et al. (2014) for more information.
+    mu_criterion: float = 0.85
+        The chosen mu-criterion. See Schönleber et al. (2014) for more information.
 
-add_capacitance: bool = False
-    Add an additional capacitance in series with the rest of the circuit.
+    add_capacitance: bool = False
+        Add an additional capacitance in series with the rest of the circuit.
 
-add_inductance: bool = False
-    Add an additional inductance in series with the rest of the circuit.
-    Applies only to the "cnls" test.
+    add_inductance: bool = False
+        Add an additional inductance in series with the rest of the circuit.
+        Applies only to the "cnls" test.
 
-method: str = "leastsq"
-    The fitting method to use when performing a "cnls" test.
-    See the list of methods that are listed in the documentation for the lmfit package.
-    Methods that do not require providing bounds for all parameters or a function to calculate the Jacobian should work.
+    method: str = "leastsq"
+        The fitting method to use when performing a "cnls" test.
+        See the list of methods that are listed in the documentation for the lmfit package.
+        Methods that do not require providing bounds for all parameters or a function to calculate the Jacobian should work.
 
-max_nfev: int = -1
-    The maximum number of function evaluations when fitting.
-    A value less than one equals no limit.
-    Applies only to the "cnls" test.
+    max_nfev: int = -1
+        The maximum number of function evaluations when fitting.
+        A value less than one equals no limit.
+        Applies only to the "cnls" test.
 
-num_procs: int = -1
-    The maximum number of parallel processes to use when performing a test.
-    A value less than one results in using the number of cores returned by multiprocessing.cpu_count.
-    Applies only to the "cnls" test.
+    num_procs: int = -1
+        The maximum number of parallel processes to use when performing a test.
+        A value less than one results in using the number of cores returned by multiprocessing.cpu_count.
+        Applies only to the "cnls" test.
 
-Returns
--------
-KramersKronigResult
+    Returns
+    -------
+    KramersKronigResult
     """
     assert isinstance(data, DataSet), (
         type(data),
@@ -720,12 +738,12 @@ KramersKronigResult
         type(test),
         test,
     )
-    assert type(num_RC) is int, (
+    assert issubdtype(type(num_RC), integer), (
         type(num_RC),
         num_RC,
     )
     assert num_RC <= data.get_num_points(), f"{num_RC=} > {data.get_num_points()=}"
-    assert type(mu_criterion) is float, (
+    assert issubdtype(type(mu_criterion), floating), (
         type(mu_criterion),
         mu_criterion,
     )
@@ -743,11 +761,11 @@ KramersKronigResult
         type(method),
         method,
     )
-    assert type(max_nfev) is int, (
+    assert issubdtype(type(max_nfev), integer), (
         type(max_nfev),
         max_nfev,
     )
-    assert type(num_procs) is int, (
+    assert issubdtype(type(num_procs), integer), (
         type(num_procs),
         num_procs,
     )
@@ -766,7 +784,7 @@ KramersKronigResult
     fits: List[Tuple[int, float, Circuit, float]]
     if test == "cnls":
         if num_RC > 0:
-            # Perform the test with a specific number of (RC) circuits
+            # Perform the test with a specific number of RC elements
             arguments = [
                 (
                     freq,
@@ -790,7 +808,7 @@ KramersKronigResult
             num_RC, mu, circuit, Xps = fits[0]
         else:
             num_RC = abs(num_RC) or len(freq)
-            # Find an appropriate number of (RC) circuits based on the calculated mu-value and the
+            # Find an appropriate number of RC elements based on the calculated mu-value and the
             # provided threshold value. Use multiple parallel processes if possible.
             arguments = [
                 (
@@ -889,41 +907,41 @@ def perform_exploratory_tests(
     num_procs: int = -1,
 ) -> List[KramersKronigResult]:
     """
-Performs a batch of linear Kramers-Kronig tests.
+    Performs a batch of linear Kramers-Kronig tests.
 
-Parameters
-----------
-data: DataSet
-    The data set to be tested.
+    Parameters
+    ----------
+    data: DataSet
+        The data set to be tested.
 
-test: str = "complex"
-    See perform_test for details.
+    test: str = "complex"
+        See perform_test for details.
 
-num_RCs: List[int] = []
-    A list of integers representing the various number of parallel RC circuits to test.
-    An empty list results in all possible numbers of parallel RC circuits up to the total number of frequencies being tested.
+    num_RCs: List[int] = []
+        A list of integers representing the various number of RC elements to test.
+        An empty list results in all possible numbers of RC elements up to the total number of frequencies being tested.
 
-mu_criterion: float = 0.85
-    See perform_test for details.
+    mu_criterion: float = 0.85
+        See perform_test for details.
 
-add_capacitance: bool = False
-    See perform_test for details.
+    add_capacitance: bool = False
+        See perform_test for details.
 
-add_inductance: bool = False
-    See perform_test for details.
+    add_inductance: bool = False
+        See perform_test for details.
 
-method: str = "leastsq"
-    See perform_test for details.
+    method: str = "leastsq"
+        See perform_test for details.
 
-max_nfev: int = -1
-    See perform_test for details.
+    max_nfev: int = -1
+        See perform_test for details.
 
-num_procs: int = -1
-    See perform_test for details.
+    num_procs: int = -1
+        See perform_test for details.
 
-Returns
--------
-List[KramersKronigResult]
+    Returns
+    -------
+    List[KramersKronigResult]
     """
     assert isinstance(data, DataSet), (
         type(data),
@@ -938,12 +956,12 @@ List[KramersKronigResult]
         type(num_RCs),
         num_RCs,
     )
-    assert all(map(lambda _: type(_) is int, num_RCs))
+    assert all(map(lambda _: issubdtype(type(_), integer), num_RCs))
     if len(num_RCs) > 0:
         assert (
             max(num_RCs) <= data.get_num_points()
         ), f"{max(num_RCs)=} > {data.get_num_points()=}"
-    assert type(mu_criterion) is float, (
+    assert issubdtype(type(mu_criterion), floating), (
         type(mu_criterion),
         mu_criterion,
     )
@@ -960,11 +978,11 @@ List[KramersKronigResult]
         type(method),
         method,
     )
-    assert type(max_nfev) is int, (
+    assert issubdtype(type(max_nfev), integer), (
         type(max_nfev),
         max_nfev,
     )
-    assert type(num_procs) is int, (
+    assert issubdtype(type(num_procs), integer), (
         type(num_procs),
         num_procs,
     )
@@ -1049,32 +1067,32 @@ def score_test_results(
     results: List[KramersKronigResult], mu_criterion: float
 ) -> List[Tuple[float, KramersKronigResult]]:
     """
-Assign scores to test results as an alternative to just using the mu-value generated when using the procedure described by Schönleber et al. (2014).
-The mu-value can in some cases fluctuate wildly at low numbers of parallel RC circuits and result in false positives (i.e. the mu-value briefly dips below the mu-criterion only to rises above it again).
-The score is equal to -numpy.inf for results with mu-values greater than or equal to the mu-criterion.
-For results with mu-values below the mu-criterion, the score is calculated based on the pseudo chi-squared value of the result and on the difference between the mu-criterion and the result's mu-value.
-The results and their corresponding scores are returned as a list of tuples.
-The list is sorted from the highest score to the lowest score.
-The result with the highest score should be a good initial guess for a suitable candidate.
+    Assign scores to test results as an alternative to just using the mu-value generated when using the procedure described by Schönleber et al. (2014).
+    The mu-value can in some cases fluctuate wildly at low numbers of RC elements and result in false positives (i.e. the mu-value briefly dips below the mu-criterion only to rises above it again).
+    The score is equal to -numpy.inf for results with mu-values greater than or equal to the mu-criterion.
+    For results with mu-values below the mu-criterion, the score is calculated based on the pseudo chi-squared value of the result and on the difference between the mu-criterion and the result's mu-value.
+    The results and their corresponding scores are returned as a list of tuples.
+    The list is sorted from the highest score to the lowest score.
+    The result with the highest score should be a good initial guess for a suitable candidate.
 
-Parameters
-----------
-results: List[KramersKronigResult]
-    The result to score.
+    Parameters
+    ----------
+    results: List[KramersKronigResult]
+        The result to score.
 
-mu_criterion: float
-    The mu_criterion to use.
+    mu_criterion: float
+        The mu_criterion to use.
 
-Returns
--------
-List[Tuple[float, KramersKronigResult]]
+    Returns
+    -------
+    List[Tuple[float, KramersKronigResult]]
     """
     assert type(results) is list, (
         type(results),
         results,
     )
     assert all(map(lambda _: type(_) is KramersKronigResult, results)), results
-    assert type(mu_criterion) is float, (
+    assert issubdtype(type(mu_criterion), floating), (
         type(mu_criterion),
         mu_criterion,
     )
