@@ -18,13 +18,33 @@
 # the LICENSES folder.
 
 import cmath
-from math import pi
 from collections import OrderedDict
-from os.path import basename, splitext
-from typing import Callable, Dict, List, Optional, Tuple, Union
-from numpy import allclose, angle, array, log10 as log, mean, ndarray, radians
-from pandas import DataFrame
+from math import pi
+from os.path import (
+    basename,
+    splitext,
+)
+from typing import (
+    Callable,
+    Dict,
+    List,
+    Optional,
+    Tuple,
+    Union,
+)
 from uuid import uuid4
+from numpy import (
+    allclose,
+    angle,
+    array,
+    integer,
+    issubdtype,
+    log10 as log,
+    mean,
+    ndarray,
+    radians,
+)
+from pandas import DataFrame
 
 
 VERSION: int = 1
@@ -54,29 +74,29 @@ def _parse_v1(dictionary: dict) -> dict:
 
 class DataSet:
     """
-A class that represents an impedance spectrum.
-The data points can be masked, which results in those data points being omitted from any analyses and visualization.
+    A class that represents an impedance spectrum.
+    The data points can be masked, which results in those data points being omitted from any analyses and visualization.
 
-Parameters
-----------
-frequency: ndarray
-    A 1-dimensional array of frequencies in hertz.
+    Parameters
+    ----------
+    frequency: ndarray
+        A 1-dimensional array of frequencies in hertz.
 
-impedance: ndarray
-    A 1-dimensional array of complex impedances in ohms.
+    impedance: ndarray
+        A 1-dimensional array of complex impedances in ohms.
 
-mask: Dict[int, bool] = {}
-    A mapping of integer indices to boolean values where a value of True means that the data point is to be omitted.
+    mask: Dict[int, bool] = {}
+        A mapping of integer indices to boolean values where a value of True means that the data point is to be omitted.
 
-path: str = ""
-    The path to the file that has been parsed to generate this DataSet instance.
+    path: str = ""
+        The path to the file that has been parsed to generate this DataSet instance.
 
-label: str = ""
-    The label assigned to this DataSet instance.
+    label: str = ""
+        The label assigned to this DataSet instance.
 
-uuid: str = ""
-    The universivally unique identifier assigned to this DataSet instance.
-    If empty, then one will be automatically assigned.
+    uuid: str = ""
+        The universivally unique identifier assigned to this DataSet instance.
+        If empty, then one will be automatically assigned.
     """
 
     def __init__(
@@ -99,7 +119,10 @@ uuid: str = ""
         ), f"{path=} ({label=}): {len(frequency)=}, {len(impedance)=}"
         assert type(mask) is dict
         assert all(
-            map(lambda _: type(_[0]) is int and type(_[1]) is bool, mask.items())
+            map(
+                lambda _: issubdtype(type(_[0]), integer) and type(_[1]) is bool,
+                mask.items(),
+            )
         ), mask
         assert type(path) is str
         assert type(label) is str
@@ -120,12 +143,12 @@ uuid: str = ""
 
     def subtract_impedance(self, Z: Union[complex, List[complex], ndarray]):
         """
-Subtract either the same complex value from all data points or a unique complex value for each data point in this DataSet.
+        Subtract either the same complex value from all data points or a unique complex value for each data point in this DataSet.
 
-Parameters
-----------
-Z: Union[complex, List[complex], ndarray]
-    The complex value(s) to subtract from this DataSet's impedances.
+        Parameters
+        ----------
+        Z: Union[complex, List[complex], ndarray]
+            The complex value(s) to subtract from this DataSet's impedances.
         """
         if type(Z) is list or type(Z) is ndarray:
             assert all(map(lambda _: hasattr(_, "real") and hasattr(_, "imag"), Z)), (
@@ -156,35 +179,35 @@ Z: Union[complex, List[complex], ndarray]
     @classmethod
     def from_dict(Class, dictionary: dict) -> "DataSet":
         """
-Create a DataSet from a dictionary.
+        Create a DataSet from a dictionary.
 
-Parameters
-----------
-dictionary: dict
-    A dictionary containing at least the frequencies, and the real and the imaginary parts of the impedances.
+        Parameters
+        ----------
+        dictionary: dict
+            A dictionary containing at least the frequencies, and the real and the imaginary parts of the impedances.
 
-Returns
--------
-DataSet
+        Returns
+        -------
+        DataSet
         """
         return Class(**Class._parse(dictionary))
 
     @classmethod
     def copy(Class, data: "DataSet", label: Optional[str] = None) -> "DataSet":
         """
-Create a copy of an existing DataSet.
+        Create a copy of an existing DataSet.
 
-Parameters
-----------
-data: DataSet
-    The existing DataSet to make a copy of.
+        Parameters
+        ----------
+        data: DataSet
+            The existing DataSet to make a copy of.
 
-label: Optional[str] = None
-    The label that the copy should have.
+        label: Optional[str] = None
+            The label that the copy should have.
 
-Returns
--------
-DataSet
+        Returns
+        -------
+        DataSet
         """
         assert type(data) is Class
         assert type(label) is str or label is None
@@ -197,21 +220,23 @@ DataSet
     @classmethod
     def average(Class, data_sets: List["DataSet"], label: str = "Average") -> "DataSet":
         """
-Create a DataSet by averaging the impedances of multiple DataSet instances.
+        Create a DataSet by averaging the impedances of multiple DataSet instances.
 
-Parameters
-----------
-data_sets: List[DataSet]
-    The DataSet instances to average.
+        Parameters
+        ----------
+        data_sets: List[DataSet]
+            The DataSet instances to average.
 
-label: str = "Average"
-    The label that the new DataSet should have.
+        label: str = "Average"
+            The label that the new DataSet should have.
 
-Returns
--------
-DataSet
+        Returns
+        -------
+        DataSet
         """
-        assert type(data_sets) is list and all(map(lambda _: type(_) is Class, data_sets))
+        assert type(data_sets) is list and all(
+            map(lambda _: type(_) is Class, data_sets)
+        )
         assert type(label) is str
         freqs: List[ndarray] = list(
             map(lambda _: _.get_frequency(masked=None), data_sets)
@@ -233,69 +258,69 @@ DataSet
 
     def get_path(self) -> str:
         """
-Get the path to the file that was parsed to generate this DataSet.
+        Get the path to the file that was parsed to generate this DataSet.
 
-Returns
--------
-str
+        Returns
+        -------
+        str
         """
         return self._path
 
     def set_path(self, path: str):
         """
-Set the path to the file that was parsed to generate this DataSet.
+        Set the path to the file that was parsed to generate this DataSet.
 
-Parameters
-----------
-path: str
-    The path.
+        Parameters
+        ----------
+        path: str
+            The path.
         """
         assert type(path) is str
         self._path = path
 
     def get_label(self) -> str:
         """
-Get the label assigned to this DataSet.
+        Get the label assigned to this DataSet.
 
-Returns
--------
-str
+        Returns
+        -------
+        str
         """
         return self._label
 
     def set_label(self, label: str):
         """
-Set the label assigned to this DataSet.
+        Set the label assigned to this DataSet.
 
-Parameters
-----------
-label: str
-    The new label.
+        Parameters
+        ----------
+        label: str
+            The new label.
         """
         assert type(label) is str
         self._label = label
 
     def set_mask(self, mask: Dict[int, bool]):
         """
-Set the mask for this DataSet.
+        Set the mask for this DataSet.
 
-Parameters
-----------
-mask: Dict[int, bool]
-    The new mask.
-    The keys must be zero-based indices and the values must be boolean values.
-    True means that the data point is to be omitted and False means that the data point is to be included.
+        Parameters
+        ----------
+        mask: Dict[int, bool]
+            The new mask.
+            The keys must be zero-based indices and the values must be boolean values.
+            True means that the data point is to be omitted and False means that the data point is to be included.
         """
         assert (
             type(mask) is dict
-            and all(map(lambda _: type(_) is int, mask.keys()))
+            and all(map(lambda _: issubdtype(type(_), integer), mask.keys()))
             and all(map(lambda _: type(_) is bool, mask.values()))
-        )
+        ), mask
         mask = mask.copy()
         i: int
         flag: bool
         for i, flag in mask.items():
-            assert type(i) is int, type(i)
+            assert issubdtype(type(i), integer), type(i)
             assert type(flag) is bool, type(flag)
         for i in list(mask.keys()):
             if i < 0 or i >= self._num_points:
@@ -307,30 +332,30 @@ mask: Dict[int, bool]
 
     def get_mask(self) -> Dict[int, bool]:
         """
-Get the mask for this DataSet.
-The keys are zero-based indices and the values are booleans.
-True means that the data point is to be omitted and False means that the data point is to be included.
+        Get the mask for this DataSet.
+        The keys are zero-based indices and the values are booleans.
+        True means that the data point is to be omitted and False means that the data point is to be included.
 
-Returns
--------
-Dict[int, bool]
+        Returns
+        -------
+        Dict[int, bool]
         """
         return self._mask.copy()
 
     def get_frequency(self, masked: Optional[bool] = False) -> ndarray:
         """
-Get the frequencies in this DataSet.
+        Get the frequencies in this DataSet.
 
-Parameters
-----------
-masked: Optional[bool] = False
-    None means that all frequencies are returned.
-    True means that only frequencies that are to be omitted are returned.
-    False means that only frequencies that are to be included are returned.
+        Parameters
+        ----------
+        masked: Optional[bool] = False
+            None means that all frequencies are returned.
+            True means that only frequencies that are to be omitted are returned.
+            False means that only frequencies that are to be included are returned.
 
-Returns
--------
-ndarray
+        Returns
+        -------
+        ndarray
         """
         assert type(masked) is bool or masked is None
         if masked is None:
@@ -347,18 +372,18 @@ ndarray
 
     def get_impedance(self, masked: Optional[bool] = False) -> ndarray:
         """
-Get the complex impedances in this DataSet.
+        Get the complex impedances in this DataSet.
 
-Parameters
-----------
-masked: Optional[bool] = False
-    None means that all impedances are returned.
-    True means that only impedances that are to be omitted are returned.
-    False means that only impedances that are to be included are returned.
+        Parameters
+        ----------
+        masked: Optional[bool] = False
+            None means that all impedances are returned.
+            True means that only impedances that are to be omitted are returned.
+            False means that only impedances that are to be included are returned.
 
-Returns
--------
-ndarray
+        Returns
+        -------
+        ndarray
         """
         assert type(masked) is bool or masked is None
         if masked is None:
@@ -375,86 +400,86 @@ ndarray
 
     def get_real(self, masked: Optional[bool] = False) -> ndarray:
         """
-Get the real parts of the impedances in this DataSet.
+        Get the real parts of the impedances in this DataSet.
 
-Parameters
-----------
-masked: Optional[bool] = False
-    None means that all impedances are returned.
-    True means that only impedances that are to be omitted are returned.
-    False means that only impedances that are to be included are returned.
+        Parameters
+        ----------
+        masked: Optional[bool] = False
+            None means that all impedances are returned.
+            True means that only impedances that are to be omitted are returned.
+            False means that only impedances that are to be included are returned.
 
-Returns
--------
-ndarray
+        Returns
+        -------
+        ndarray
         """
         return self.get_impedance(masked=masked).real
 
     def get_imaginary(self, masked: Optional[bool] = False) -> ndarray:
         """
-Get the imaginary parts of the impedances in this DataSet.
+        Get the imaginary parts of the impedances in this DataSet.
 
-Parameters
-----------
-masked: Optional[bool] = False
-    None means that all impedances are returned.
-    True means that only impedances that are to be omitted are returned.
-    False means that only impedances that are to be included are returned.
+        Parameters
+        ----------
+        masked: Optional[bool] = False
+            None means that all impedances are returned.
+            True means that only impedances that are to be omitted are returned.
+            False means that only impedances that are to be included are returned.
 
-Returns
--------
-ndarray
+        Returns
+        -------
+        ndarray
         """
         return self.get_impedance(masked=masked).imag
 
     def get_magnitude(self, masked: Optional[bool] = False) -> ndarray:
         """
-Get the absolute magnitudes of the impedances in this DataSet.
+        Get the absolute magnitudes of the impedances in this DataSet.
 
-Parameters
-----------
-masked: Optional[bool] = False
-    None means that all impedances are returned.
-    True means that only impedances that are to be omitted are returned.
-    False means that only impedances that are to be included are returned.
+        Parameters
+        ----------
+        masked: Optional[bool] = False
+            None means that all impedances are returned.
+            True means that only impedances that are to be omitted are returned.
+            False means that only impedances that are to be included are returned.
 
-Returns
--------
-ndarray
+        Returns
+        -------
+        ndarray
         """
         return abs(self.get_impedance(masked=masked))
 
     def get_phase(self, masked: Optional[bool] = False) -> ndarray:
         """
-Get the phase angles/shifts of the impedances in this DataSet in degrees.
+        Get the phase angles/shifts of the impedances in this DataSet in degrees.
 
-Parameters
-----------
-masked: Optional[bool] = False
-    None means that all impedances are returned.
-    True means that only impedances that are to be omitted are returned.
-    False means that only impedances that are to be included are returned.
+        Parameters
+        ----------
+        masked: Optional[bool] = False
+            None means that all impedances are returned.
+            True means that only impedances that are to be omitted are returned.
+            False means that only impedances that are to be included are returned.
 
-Returns
--------
-ndarray
+        Returns
+        -------
+        ndarray
         """
         return angle(self.get_impedance(masked=masked), deg=True)
 
     def get_num_points(self, masked: Optional[bool] = False) -> int:
         """
-Get the number of data points in this DataSet
+        Get the number of data points in this DataSet
 
-Parameters
-----------
-masked: Optional[bool] = False
-    None means that all impedances are returned.
-    True means that only impedances that are to be omitted are returned.
-    False means that only impedances that are to be included are returned.
+        Parameters
+        ----------
+        masked: Optional[bool] = False
+            None means that all impedances are returned.
+            True means that only impedances that are to be omitted are returned.
+            False means that only impedances that are to be included are returned.
 
-Returns
--------
-int
+        Returns
+        -------
+        int
         """
         return len(self.get_impedance(masked=masked))
 
@@ -462,18 +487,18 @@ int
         self, masked: Optional[bool] = False
     ) -> Tuple[ndarray, ndarray]:
         """
-Get the data necessary to plot this DataSet as a Nyquist plot: the real and the negative imaginary parts of the impedances.
+        Get the data necessary to plot this DataSet as a Nyquist plot: the real and the negative imaginary parts of the impedances.
 
-Parameters
-----------
-masked: Optional[bool] = False
-    None means that all impedances are returned.
-    True means that only impedances that are to be omitted are returned.
-    False means that only impedances that are to be included are returned.
+        Parameters
+        ----------
+        masked: Optional[bool] = False
+            None means that all impedances are returned.
+            True means that only impedances that are to be omitted are returned.
+            False means that only impedances that are to be included are returned.
 
-Returns
--------
-Tuple[ndarray, ndarray]
+        Returns
+        -------
+        Tuple[ndarray, ndarray]
         """
         Z: ndarray = self.get_impedance(masked=masked)
         return (
@@ -485,18 +510,18 @@ Tuple[ndarray, ndarray]
         self, masked: Optional[bool] = False
     ) -> Tuple[ndarray, ndarray, ndarray]:
         """
-Get the data necessary to plot this DataSet as a Bode plot: the base-10 logarithms of the frequencies, the base-10 logarithms of the absolute magnitudes of the impedances, and the negative phase angles/shifts of the impedances in degrees.
+        Get the data necessary to plot this DataSet as a Bode plot: the base-10 logarithms of the frequencies, the base-10 logarithms of the absolute magnitudes of the impedances, and the negative phase angles/shifts of the impedances in degrees.
 
-Parameters
-----------
-masked: Optional[bool] = False
-    None means that all impedances are returned.
-    True means that only impedances that are to be omitted are returned.
-    False means that only impedances that are to be included are returned.
+        Parameters
+        ----------
+        masked: Optional[bool] = False
+            None means that all impedances are returned.
+            True means that only impedances that are to be omitted are returned.
+            False means that only impedances that are to be included are returned.
 
-Returns
--------
-Tuple[ndarray, ndarray, ndarray]
+        Returns
+        -------
+        Tuple[ndarray, ndarray, ndarray]
         """
         f: ndarray = self.get_frequency(masked=masked)
         Z: ndarray = self.get_impedance(masked=masked)
@@ -508,11 +533,11 @@ Tuple[ndarray, ndarray, ndarray]
 
     def to_dict(self) -> dict:
         """
-Get a dictionary that represents this DataSet, can be used to serialize the DataSet (e.g. as a JSON file), and then used to recreate this DataSet.
+        Get a dictionary that represents this DataSet, can be used to serialize the DataSet (e.g. as a JSON file), and then used to recreate this DataSet.
 
-Returns
--------
-dict
+        Returns
+        -------
+        dict
         """
         return {
             "version": VERSION,
@@ -537,39 +562,39 @@ dict
         negative_phase: bool = False,
     ) -> DataFrame:
         """
-Create a pandas.DataFrame instance from this DataSet.
+        Create a pandas.DataFrame instance from this DataSet.
 
-Parameters
-----------
-masked: Optional[bool] = False
-    None means that all impedances are returned.
-    True means that only impedances that are to be omitted are returned.
-    False means that only impedances that are to be included are returned.
+        Parameters
+        ----------
+        masked: Optional[bool] = False
+            None means that all impedances are returned.
+            True means that only impedances that are to be omitted are returned.
+            False means that only impedances that are to be included are returned.
 
-frequency_label: str = "f (Hz)"
-    The label assigned to the frequency data.
+        frequency_label: str = "f (Hz)"
+            The label assigned to the frequency data.
 
-real_label: Optional[str] = "Zre (ohm)"
-    The label assigned to the real part of the impedance data.
+        real_label: Optional[str] = "Zre (ohm)"
+            The label assigned to the real part of the impedance data.
 
-imaginary_label: Optional[str] = "Zim (ohm)"
-    The label assigned to the imaginary part of the impedance data.
+        imaginary_label: Optional[str] = "Zim (ohm)"
+            The label assigned to the imaginary part of the impedance data.
 
-magnitude_label: Optional[str] = "|Z| (ohm)"
-    The label assigned to the magnitude of the impedance data.
+        magnitude_label: Optional[str] = "|Z| (ohm)"
+            The label assigned to the magnitude of the impedance data.
 
-phase_label: Optional[str] = "phase angle (deg.)"
-    The label assigned to the phase of the imedance data.
+        phase_label: Optional[str] = "phase angle (deg.)"
+            The label assigned to the phase of the imedance data.
 
-negative_imaginary: bool = False
-    Whether or not the sign of the imaginary part of the impedance data should be inverted.
+        negative_imaginary: bool = False
+            Whether or not the sign of the imaginary part of the impedance data should be inverted.
 
-negative_phase: bool = False
-    Whether or not the sign of the phase of the impedance data should be inverted.
+        negative_phase: bool = False
+            Whether or not the sign of the phase of the impedance data should be inverted.
 
-Returns
--------
-DataFrame
+        Returns
+        -------
+        DataFrame
         """
         assert type(frequency_label) is str
         assert type(real_label) is str or real_label is None
@@ -595,22 +620,22 @@ DataFrame
 
 def dataframe_to_dataset(df: DataFrame, path: str, label: str = "") -> DataSet:
     """
-Convert a pandas.DataFrame into a DataSet.
+    Convert a pandas.DataFrame into a DataSet.
 
-Parameters
-----------
-df: DataFrame
-    The DataFrame to be converted.
+    Parameters
+    ----------
+    df: DataFrame
+        The DataFrame to be converted.
 
-path: str
-    The path to the file that was used to create the DataFrame.
+    path: str
+        The path to the file that was used to create the DataFrame.
 
-label: str = ""
-    The label assigned to the new DataSet.
+    label: str = ""
+        The label assigned to the new DataSet.
 
-Returns
--------
-DataSet
+    Returns
+    -------
+    DataSet
     """
     assert type(df) is DataFrame
     assert type(path) is str
@@ -681,6 +706,11 @@ DataSet
             Z: complex = cmath.rect(mag, phi)
             real.append(Z.real)
             imaginary.append(Z.imag)
+    assert len(frequency) == len(real) == len(imaginary) > 0, (
+        len(frequency),
+        len(real),
+        len(imaginary),
+    )
     return DataSet(
         array(frequency),
         array(list(map(lambda _: complex(*_), zip(real, imaginary)))),
